@@ -2,9 +2,11 @@ package agent
 
 import (
 	"bytes"
+	"context"
 	"encoding/json"
 	"fmt"
 	"io"
+	"net"
 	"net/http"
 	"net/url"
 	"strconv"
@@ -13,9 +15,68 @@ import (
 
 	"github.com/pkg/errors"
 	log "github.com/sirupsen/logrus"
+	"golang.org/x/sys/unix"
+	agentapi "isc.org/stork/api"
 	storkutil "isc.org/stork/util"
 )
 
+// The GRPC handler used in the registration with the server token to respond
+// to the ping request. It doesn't support other GRPC methods.
+type grpcPingHandler struct {
+	agentapi.UnimplementedAgentServer
+}
+
+// Respond to ping request from the server. It assures the server that the
+// connection from the server to client is established. It is used in server
+// token registration procedure.
+func (grpcPingHandler) Ping(ctx context.Context, in *agentapi.PingReq) (*agentapi.PingRsp, error) {
+	rsp := agentapi.PingRsp{}
+	return &rsp, nil
+}
+
+// Starts the GRPC server to handle the ping request from the Stork server.
+// It doesn't support other operations.
+// Returns the function that must be called to stop the server or an error.
+func runPingGRPCServer(host string, port int) (func(), error) {
+	server, err := newGRPCServerWithTLS()
+	if err != nil {
+		err = errors.WithMessage(err, "cannot setup the GRPC server")
+		return nil, err
+	}
+
+	handler := &grpcPingHandler{}
+
+	// Install gRPC API handlers.
+	agentapi.RegisterAgentServer(server, handler)
+
+	// Prepare listener on configured address.
+	addr := net.JoinHostPort(host, fmt.Sprint(port))
+	listener, err := net.Listen("tcp", addr)
+	if err != nil {
+		if errors.Is(err, unix.EADDRINUSE) {
+			err = errors.Wrapf(err,
+				"agent registration using the server token requires that the "+
+					"existing Stork agent instances are stopped; Stork agent "+
+					"detected a program bound to port %d; if it is a Stork agent "+
+					"instance, please shut it down before attempting the "+
+					"re-registration; if it is a different program, please "+
+					"configure the Stork agent to use an available port", port)
+		} else {
+			err = errors.Wrap(err, "cannot setup the GRPC listener")
+		}
+
+		return nil, err
+	}
+
+	go func() {
+		if err := server.Serve(listener); err != nil {
+			log.WithError(err).Errorf("failed to serve on: %s", addr)
+		}
+	}()
+
+	return server.GracefulStop, nil
+}
+
 // Generate or regenerate agent key and CSR (Certificate Signing
 // Request). They are generated when they do not exist. They are
 // regenerated only if regenCerts is true. If they exist and
@@ -305,15 +366,13 @@ func pingAgentViaServer(client *HTTPClient, baseSrvURL *url.URL, machineID int64
 // in the server. If server token is empty (in automatic registration or
 // when it is not provided in manual registration) then agent is added to
 // server but requires manual authorization in web UI.
-func Register(serverURL, serverToken, agentHost string, agentPort int, regenCerts bool, retry bool, httpClient *HTTPClient) bool {
+func Register(serverURL, serverToken, agentHost string, agentPort int, regenCerts bool, retry bool, httpClient *HTTPClient) error {
 	// parse URL to server
 	baseSrvURL, err := url.Parse(serverURL)
 	if err != nil {
-		log.WithError(err).Errorf("Cannot parse server URL: %s", serverURL)
-		return false
+		return errors.Wrapf(err, "cannot parse server URL: %s", serverURL)
 	} else if baseSrvURL.String() == "" {
-		log.Error("Server URL is empty")
-		return false
+		return errors.Errorf("server URL is empty")
 	}
 
 	certStore := NewCertStoreDefault()
@@ -321,20 +380,17 @@ func Register(serverURL, serverToken, agentHost string, agentPort int, regenCert
 	// Generate agent private key and cert. If they already exist then regenerate them if forced.
 	csrPEM, err := generateCSR(certStore, agentHost, regenCerts)
 	if err != nil {
-		log.WithError(err).Error("Problem generating certs")
-		return false
+		return errors.WithMessage(err, "problem generating certs")
 	}
 
 	agentToken, err := certStore.ReadToken()
 	if err != nil {
-		log.WithError(err).Error("cannot load the agent token")
-		return false
+		return errors.WithMessage(err, "cannot load the agent token")
 	}
 
 	caCertFingerprint, err := certStore.ReadRootCAFingerprint()
 	if err != nil {
-		log.WithError(err).Error("cannot load the CA cert fingerprint")
-		return false
+		return errors.WithMessage(err, "cannot load the CA cert fingerprint")
 	}
 
 	// Use cert fingerprint as agent token.
@@ -355,8 +411,7 @@ func Register(serverURL, serverToken, agentHost string, agentPort int, regenCert
 	// register new machine i.e. current agent
 	reqPayload, err := prepareRegistrationRequestPayload(csrPEM, serverToken, agentToken, agentHost, agentPort, caCertFingerprint)
 	if err != nil {
-		log.Errorln(err.Error())
-		return false
+		return errors.WithMessage(err, "cannot prepare the registration request")
 	}
 	log.Println("Try to register agent in Stork Server")
 	// If the machine is already registered then the ID is returned. If the
@@ -365,8 +420,7 @@ func Register(serverURL, serverToken, agentHost string, agentPort int, regenCert
 	// and should be stored.
 	machineID, serverCACert, agentCert, serverCertFingerprint, err := registerAgentInServer(httpClient, baseSrvURL, reqPayload, retry)
 	if err != nil {
-		log.WithError(err).Error("Problem registering machine")
-		return false
+		return errors.WithMessage(err, "problem registering machine")
 	}
 
 	// store certs
@@ -374,13 +428,19 @@ func Register(serverURL, serverToken, agentHost string, agentPort int, regenCert
 	if serverCACert != nil && agentCert != nil {
 		err = checkAndStoreCerts(certStore, serverCACert, agentCert, serverCertFingerprint)
 		if err != nil {
-			log.WithError(err).Errorf("Problem with certs")
-			return false
+			return errors.WithMessage(err, "problem with certs")
 		}
 	}
 
 	if serverToken != "" {
-		// invoke getting machine state via server
+		// Start the listener to handle the ping request.
+		teardown, err := runPingGRPCServer(agentHost, agentPort)
+		if err != nil {
+			return errors.WithMessage(err, "cannot run the GRPC server to handle Ping")
+		}
+		defer teardown()
+
+		// Invoke getting machine state via server.
 		for i := 1; i < 4; i++ {
 			err = pingAgentViaServer(httpClient, baseSrvURL, machineID, serverToken, agentToken)
 			if err == nil {
@@ -392,10 +452,9 @@ func Register(serverURL, serverToken, agentHost string, agentPort int, regenCert
 			}
 		}
 		if err != nil {
-			log.WithError(err).Errorf("Cannot ping machine")
-			return false
+			return errors.WithMessage(err, "cannot ping machine")
 		}
 	}
 
-	return true
+	return nil
 }
