@@ -50,13 +50,54 @@ func TestReadIntervalFromDatabase(t *testing.T) {
 	_ = dbmodel.SetSettingInt(db, "kea_hosts_puller_interval", 10)
 
 	// Assert
-	require.EqualValues(t, 1, initialInterval)
+	require.EqualValues(t, 1*time.Second, initialInterval)
 	require.Eventually(t, func() bool {
 		currentInterval := puller.GetInterval()
-		return currentInterval == 10
+		return currentInterval == 10*time.Second
 	}, 5*time.Second, time.Second, "puller didn't update the interval")
 }
 
+// Test that  the puller doesn't stop when the read interval from the database
+// fails.
+func TestExecutePullerWhileDatabaseIsDown(t *testing.T) {
+	// Arrange
+	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
+	defer teardown()
+	_ = dbmodel.InitializeSettings(db, 0)
+	_ = dbmodel.SetSettingInt(db, "kea_hosts_puller_interval", 1)
+
+	var callCount atomic.Uint64
+	callCount.Store(0)
+
+	puller, _ := NewPeriodicPuller(db, nil, "test puller", "kea_hosts_puller_interval",
+		func() error {
+			// Increment a counter to check if the puller is still running.
+			callCount.Add(1)
+			return nil
+		})
+	defer puller.Shutdown()
+
+	// Wait for the initial puller execution.
+	require.Eventually(t, func() bool {
+		return callCount.Load() > 0
+	}, 5*time.Second, time.Second)
+
+	// Stop the database to simulate a failure.
+	teardown()
+
+	// Get the counter value after the database failure.
+	callCountAfterFailure := callCount.Load()
+
+	// Act & Assert
+	require.Eventually(t, func() bool {
+		// Periodic executor updates the interval after the pulling. So, the
+		// counter is incremented on failure. If the puller is still running,
+		// the counter should be incremented more times.
+		currentCallCount := callCount.Load()
+		return currentCallCount >= callCountAfterFailure+2
+	}, 5*time.Second, time.Second)
+}
+
 // Test that the interval setting name is returned properly.
 func TestGetIntervalName(t *testing.T) {
 	// Arrange
