@@ -269,7 +269,7 @@ func rpsTestAddMachine(t *testing.T, db *dbops.PgDB, dhcp4Active bool, dhcp6Acti
 }
 
 // Verifies RPS values for both intervals for a given daemon.
-func checkDaemonRpsStats(t *testing.T, db *dbops.PgDB, keaDaemonID int64, interval1 int, interval2 int) {
+func checkDaemonRpsStats(t *testing.T, db *dbops.PgDB, keaDaemonID int64, interval1 float32, interval2 float32) {
 	daemon := &dbmodel.KeaDHCPDaemon{}
 	err := db.Model(daemon).
 		Where("kea_daemon_id = ?", keaDaemonID).
@@ -282,15 +282,15 @@ func checkDaemonRpsStats(t *testing.T, db *dbops.PgDB, keaDaemonID int64, interv
 	// be rounded down. Let's add a margin of 1 to these checks. Without it, the test
 	// results were unstable.
 	require.Condition(t, func() bool {
-		return daemon.Stats.RPS1 == interval1 || daemon.Stats.RPS1 == interval1-1
+		return daemon.Stats.RPS1 <= interval1 || daemon.Stats.RPS1 >= interval1-1
 	}, "RPS1: %d, interval1: %d", daemon.Stats.RPS1, interval1)
 	require.Condition(t, func() bool {
-		return daemon.Stats.RPS2 == interval2 || daemon.Stats.RPS2 == interval2-1
+		return daemon.Stats.RPS2 <= interval2 || daemon.Stats.RPS2 >= interval2-1
 	}, "RPS2: %d, interval2: %d", daemon.Stats.RPS2, interval2)
 }
 
 // Calculate the RPS from an array of RpsIntervals.
-func getExpectedRps(rpsIntervals []*dbmodel.RpsInterval, endIdx int) int {
+func getExpectedRps(rpsIntervals []*dbmodel.RpsInterval, endIdx int) float32 {
 	var responses int64
 	var duration int64
 
@@ -303,11 +303,7 @@ func getExpectedRps(rpsIntervals []*dbmodel.RpsInterval, endIdx int) int {
 		return 0
 	}
 
-	if responses < duration {
-		return 1
-	}
-
-	return (int(responses / duration))
+	return float32(responses) / float32(duration)
 }
 
 // Marshall a given json response to a DHCP4 command and pass that into Response4Handler.
