@@ -4,9 +4,11 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/require"
+	"isc.org/stork/datamodel"
 	"isc.org/stork/server/agentcomm"
 	agentcommtest "isc.org/stork/server/agentcomm/test"
 	kea "isc.org/stork/server/apps/kea"
+	"isc.org/stork/server/configreview"
 	dbmodel "isc.org/stork/server/database/model"
 	dbtest "isc.org/stork/server/database/test"
 	storktest "isc.org/stork/server/test/dbmodel"
@@ -49,12 +51,12 @@ func TestStatePullerPullData(t *testing.T) {
 	fa.MachineState = &agentcomm.State{
 		Apps: []*agentcomm.App{
 			{
-				Type: dbmodel.AppTypeKea,
+				Type: datamodel.AppTypeKea.String(),
 				// access point is changing from 1.1.1.1 to 1.2.3.4
 				AccessPoints: agentcomm.MakeAccessPoint(dbmodel.AccessPointControl, "1.2.3.4", "", 1234),
 			},
 			{
-				Type:         dbmodel.AppTypeBind9,
+				Type:         datamodel.AppTypeBind9.String(),
 				AccessPoints: agentcomm.MakeAccessPoint(dbmodel.AccessPointControl, "1.2.3.4", "abcd", 124),
 			},
 		},
@@ -189,28 +191,37 @@ func TestConditionallyBeginKeaConfigReviews(t *testing.T) {
 	dispatcher := &storktest.FakeDispatcher{}
 
 	// New daemon. The review should be initiated.
-	conditionallyBeginKeaConfigReviews(app, state, dispatcher)
+	conditionallyBeginKeaConfigReviews(app, state, dispatcher, false)
 	require.Len(t, dispatcher.CallLog, 1)
 	require.Equal(t, "BeginReview", dispatcher.CallLog[0].CallName)
 
 	// There are no "same daemons". The review should be
 	// performed again.
-	conditionallyBeginKeaConfigReviews(app, state, dispatcher)
+	conditionallyBeginKeaConfigReviews(app, state, dispatcher, false)
 	require.Len(t, dispatcher.CallLog, 2)
 	require.Equal(t, "BeginReview", dispatcher.CallLog[1].CallName)
 
 	// Neither daemon's configuration nor dispatcher's signature
 	// have changed. The review should not be performed.
 	state.SameConfigDaemons["dhcp4"] = true
-	conditionallyBeginKeaConfigReviews(app, state, dispatcher)
+	conditionallyBeginKeaConfigReviews(app, state, dispatcher, false)
 	require.Len(t, dispatcher.CallLog, 3)
 	require.Equal(t, "GetSignature", dispatcher.CallLog[2].CallName)
 
 	// Modify the dispatcher's signature. It should result in
 	// another config review.
 	dispatcher.Signature = "new signature"
-	conditionallyBeginKeaConfigReviews(app, state, dispatcher)
+	conditionallyBeginKeaConfigReviews(app, state, dispatcher, false)
 	require.Len(t, dispatcher.CallLog, 5)
 	require.Equal(t, "GetSignature", dispatcher.CallLog[3].CallName)
 	require.Equal(t, "BeginReview", dispatcher.CallLog[4].CallName)
+
+	// Stork Agent configuration changed. The review should be performed again.
+	conditionallyBeginKeaConfigReviews(app, state, dispatcher, true)
+	require.Len(t, dispatcher.CallLog, 7)
+	require.Equal(t, "GetSignature", dispatcher.CallLog[5].CallName)
+	require.Equal(t, "BeginReview", dispatcher.CallLog[6].CallName)
+	require.Len(t, dispatcher.CallLog[6].Triggers, 2)
+	require.Equal(t, configreview.StorkAgentConfigModified, dispatcher.CallLog[6].Triggers[0])
+	require.Equal(t, configreview.ConfigModified, dispatcher.CallLog[6].Triggers[1])
 }
