@@ -1,6 +1,6 @@
 import { IdentifierComponent } from './identifier.component'
 
-import { Story, Meta, moduleMetadata, applicationConfig } from '@storybook/angular'
+import { StoryObj, Meta, moduleMetadata, applicationConfig } from '@storybook/angular'
 import { ToggleButtonModule } from 'primeng/togglebutton'
 import { NoopAnimationsModule } from '@angular/platform-browser/animations'
 import { FormsModule } from '@angular/forms'
@@ -18,13 +18,11 @@ export default {
     ],
 } as Meta
 
-const Template: Story<IdentifierComponent> = (args: IdentifierComponent) => ({
-    props: args,
-})
+type Story = StoryObj<IdentifierComponent>
 
-export const Primary = Template.bind({})
-
-Primary.args = {
-    hexValue: '73:30:6d:45:56:61:4c:75:65',
-    label: 'flex-id',
+export const Primary: Story = {
+    args: {
+        hexValue: '73:30:6d:45:56:61:4c:75:65',
+        label: 'flex-id',
+    },
 }
