@@ -475,7 +475,29 @@ describe('SubnetFormComponent', () => {
         expect(component.state.group.get('subnet').disabled).toBeTrue()
         expect(component.state.wizard).toBeFalse()
 
-        component.state.group.get('selectedDaemons').setValue([1, 2])
+        const selectedDaemons = [1, 2]
+        component.state.group.get('selectedDaemons').setValue(selectedDaemons)
+        selectedDaemons.forEach((id) => {
+            component.onDaemonsChange({
+                itemValue: id,
+            })
+        })
+        tick()
+        fixture.detectChanges()
+
+        // The daemons selection should be enabled, so there should be no helptip.
+        expect(fixture.debugElement.query(By.css('[title="Help for disabled servers selection"]'))).toBeFalsy()
+
+        // Set shared network. It should result in disabling the daemons selection.
+        component.state.group.get('sharedNetwork').setValue(3)
+        component.onSharedNetworkChange({
+            value: 3,
+        })
+        fixture.detectChanges()
+        expect(component.state.group.get('selectedDaemons')?.disabled).toBeTrue()
+
+        // It should also display the helptip.
+        expect(fixture.debugElement.query(By.css('[title="Help for disabled servers selection"]'))).toBeTruthy()
 
         const okResp: any = {
             status: 200,
@@ -489,14 +511,17 @@ describe('SubnetFormComponent', () => {
 
         const subnet = {
             subnet: '192.0.2.0/24',
-            sharedNetworkId: null,
+            sharedNetworkId: 3,
+            sharedNetwork: 'floor3',
             localSubnets: [
                 {
                     daemonId: 1,
                     pools: [],
                     prefixDelegationPools: [],
                     keaConfigSubnetParameters: {
-                        subnetLevelParameters: {},
+                        subnetLevelParameters: {
+                            options: [],
+                        },
                     },
                 },
                 {
@@ -504,7 +529,9 @@ describe('SubnetFormComponent', () => {
                     pools: [],
                     prefixDelegationPools: [],
                     keaConfigSubnetParameters: {
-                        subnetLevelParameters: {},
+                        subnetLevelParameters: {
+                            options: [],
+                        },
                     },
                 },
             ],
@@ -545,7 +572,24 @@ describe('SubnetFormComponent', () => {
         expect(component.state.group.get('subnet').disabled).toBeTrue()
         expect(component.state.wizard).toBeFalse()
 
-        component.state.group.get('selectedDaemons').setValue([3, 4])
+        const selectedDaemons = [3, 4]
+        component.state.group.get('selectedDaemons').setValue(selectedDaemons)
+        selectedDaemons.forEach((id) => {
+            component.onDaemonsChange({
+                itemValue: id,
+            })
+        })
+        tick()
+
+        // Ensure there is no shared network selected.
+        component.onSharedNetworkChange({
+            value: null,
+        })
+        fixture.detectChanges()
+
+        // Since shared network is not selected, the daemons selection should
+        // be enabled.
+        expect(component.state.group.get('selectedDaemons')?.disabled).toBeFalse()
 
         const okResp: any = {
             status: 200,
@@ -566,7 +610,9 @@ describe('SubnetFormComponent', () => {
                     pools: [],
                     prefixDelegationPools: [],
                     keaConfigSubnetParameters: {
-                        subnetLevelParameters: {},
+                        subnetLevelParameters: {
+                            options: [],
+                        },
                     },
                 },
                 {
@@ -574,7 +620,9 @@ describe('SubnetFormComponent', () => {
                     pools: [],
                     prefixDelegationPools: [],
                     keaConfigSubnetParameters: {
-                        subnetLevelParameters: {},
+                        subnetLevelParameters: {
+                            options: [],
+                        },
                     },
                 },
             ],
